# Installation

## Check your version of python

You will need python 3.11 or later. You can check your version of python by
typing into a terminal:

```
$ python3 --version
```

## Create a virtual environment

It is recommended that you install into a “virtual environment” so this
installation will not interfere with any existing Python software:

```
$ python3 -m venv /path/to/venv
$ source /path/to/venv/bin/activate
```

## Installing the library

You can now use `pip` to install the library and its dependencies:

```
$ python3 -m pip install fastcs
```

If you require a feature that is not currently released you can also install
from github:

```
$ python3 -m pip install git+https://github.com/DiamondLightSource/FastCS.git
```

The library should now be installed. There is no application entrypoint, but the library can be imported:

```
$ python3
>>> from fastcs import __version__
>>> fastcs.__version__  # doctest: +SKIP
```
